﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.IO;

namespace KinectClient
{
    class BodyPostures : List<BodyPosture>
    {
        public List<string> names;

        public BodyPostures()
        {
            names = new List<string>();
        }

        public void ReadFromFile(string fileName)// functie de citire a posturilor dintr-un fisier
        {
            using (StreamReader reader = new StreamReader(fileName))
            {
                string line = "";
                while ((line = reader.ReadLine()) != null)
                    this.Add(new BodyPosture(line));
            }
        }

        public void ReadAllPostures()// functia de citire a posturilor din mai multe fisiere
        {
            //string path = @"E:\MASTER RCC\RCC I\INOC\Proiect\KinectClient\KinectClient\bin\Debug";
            string path = Directory.GetCurrentDirectory();
            string[] files = Directory.GetFiles(path, "*.txt", SearchOption.AllDirectories);
            foreach (string file in files)
                this.Add(BodyPosture.CreateFromFile(file));
        }

        public void WriteToFile(string fileName) //functia de salvare a posturii
        {
            using (StreamWriter writer = new StreamWriter(fileName))
            {
                writer.WriteLine(this.Last().ToString());
                writer.WriteLine(this.names.Last().ToString());
            }
        }

        public void DisplayAllPostures()// functia de afisare
        {
            foreach (BodyPosture posture in this)
                Console.WriteLine(posture.ToString());
        }

        public string Classify(BodyPosture p)//functia de clasificare a posturii
        {
            double min = Double.MaxValue;
            string name = "";
            foreach (BodyPosture q in this)
            {
                double d = EuclideanDistance(q, p);
                if (d < min)
                {
                    min = d;
                    name = q.Name;
                }
            }
            return name;
        }

        public double EuclideanDistance(BodyPosture p, BodyPosture q)
        {
            double d = 0;
            for (int i = 0; i < p.Points.Count; i++)
                d += EuclideanDistance(p.Points[i], q.Points[i]);
            return d;
        }

        private double EuclideanDistance(Point3D a, Point3D b)
        {
            return Math.Sqrt((a.X - b.X) * (a.X - b.X) + (a.Y - b.Y) * (a.Y - b.Y) + (a.Z - b.Z) * (a.Z - b.Z));
        }


    }
}   